@@ -11,12 +11,12 @@
 # See the GNU General Public License at:
 # http://www.gnu.org/licenses/
 #
-network.plot <- function(top_pairs, filepathroot=NULL){
+network.plot <- function(top_pairs, filepathroot){
   pairs_i <- top_pairs$pairs_i
   pairs_j <- top_pairs$pairs_j
 
    if (is.null(filepathroot)) {
-      filename <- "NETWORK.pdf"
+      filename <- paste(tempdir(), "/NETWORK.pdf", sep="")
    } else {
       filename <- paste(filepathroot, "_NETWORK.pdf", sep="")
    }
