@@ -13,7 +13,7 @@
 # See the GNU General Public License at:
 # http://www.gnu.org/licenses/
 #
-pca_2d <- function(pca_struct, abs= 1, ord= 2, filepathroot=NULL){
+pca_2d <- function(pca_struct, abs= 1, ord= 2, filepathroot){
 #  if(is.null(abs)) abs <- 1
 #  if(is.null(ord)) ord <- 2
   
@@ -25,7 +25,7 @@ pca_2d <- function(pca_struct, abs= 1, ord= 2, filepathroot=NULL){
   pca_y <- paste("PCA", ord, sep= "")
  
   if(is.null(filepathroot)){
-     filename <- paste("PCA_", abs,"_",ord,".png")
+     filename <- paste(tempdir(),"/PCA_", abs,"_",ord,".png")
   } else {
      filename <- paste(filepathroot,"_PCA_", abs,"_",ord,".png")
   }
