@@ -11,7 +11,7 @@
 # See the GNU General Public License at:
 # http://www.gnu.org/licenses/
 #
-pca_screeplot <- function(pca_struct, filepathroot=NULL){
+pca_screeplot <- function(pca_struct, filepathroot){
   pca_coord <- pca_struct$coord
   
   nb_component <- length(pca_coord[1,])
@@ -22,7 +22,7 @@ pca_screeplot <- function(pca_struct, filepathroot=NULL){
   variances <- unlist(lapply(1:nb_component, function(x){var(pca_coord[,x])}))
 
   if(is.null(filepathroot)) {
-    filename <- "SCREEPLOT.png" 
+    filename <- paste(tempdir(), "/SCREEPLOT.png", sep="")
   } else {
     filename <- paste(filepathroot, "_SCREEPLOT.png", sep="")
   }  
